@@ -134,5 +134,5 @@ def printf(
 
 
 if __name__ == '__main__':
-    printf("thgttr", "sdsdds", Type=__Type_error)
-    printf("ssdd", Type=__Type_system)
+    printf("thgttr", "sdsdds", Type=Type_error)
+    printf("ssdd", Type=Type_system)
